/**
 * @packageDocumentation
 * @module Boolean
 */
import { Observable, ObservableInput } from 'rxjs';
/**
 * Returns an Observable that emits boolean values from passed source of values.
 *
 * @category Boolean Observables
 *
 * @typeParam T The type or types to be used to create boolean values from
 *
 * @param args Input values to create the Observable source from
 *
 * @example
 * Create an Observable that emits a single boolean value from a string, flip the value
 * ```ts
 * fromBoolean('Hello RxJS Ninja').pipe(flip()).subscribe();
 * ```
 * Output: `false`
 *
 * @example
 * Create an Observable that emits a single boolean from an array of values
 * ```ts
 * fromBoolean(['', 'Hello', 'RxJS', '']).subscribe();
 * ```
 * Output: `false, true, true, false`;
 *
 * @returns Observable that emits boolean values of the source value

 */
export declare function fromBoolean<T extends ObservableInput<unknown> | PromiseLike<unknown> | unknown | unknown[]>(...args: T[]): Observable<boolean>;
